@@ -14,7 +14,7 @@ class get_helper:
         proxy = None
         if self.app.config['proxy']['enable_proxy']:
             while True:
-                with open(self.app.config['proxy'], 'r', encoding='utf-8-sig', newline='') as f:
+                with open(self.app.config['proxy']['path'], 'r', encoding='utf-8-sig', newline='') as f:
                     proxies_list = [proxy for proxy in f]
                 proxy = choice(proxies_list)
                 if proxy not in self.app.using_proxies:
